library(curl)
library(stringi)

#Text file with metabolite names (one per line). First line should be a heading e.g. "NAME", "METABOLITE_NAME", "ID", etc
infile='met_list.txt'
####Example below
#NAME
#Ceramide d18:0/26:2
#citrate
#Trilauroyl-glycerol
#PE(aa-40:4)
#HMDB00201
#C00099
#Octenoyl-L-carnitine


#Load the example names into a data frame
DF <- read.table(infile, header = TRUE, na.strings = "-", stringsAsFactors = FALSE, quote = "", comment.char = "", sep="\t");

# Note: DF[,1] can be any data frame column containing metabolite names
mets=stri_join_list(list(DF[,1]), sep="\n")
h <- new_handle()
handle_setform(h,  metabolite_name = mets)

#run the RefMet request on the Metabolomics Workbench server
req <- curl_fetch_memory("https://www.metabolomicsworkbench.org/databases/refmet/name_to_refmet_new_min.php", handle = h)

refmet <- read.table(text = rawToChar(req$content), header = TRUE, na.strings = "-", stringsAsFactors = FALSE, quote = "", comment.char = "", sep="\t");

refmet[is.na(refmet)] <- '-'
refmet[refmet==''] <- '-'

print(refmet)
#The 'Standardized name' column contains the RefMet names
